JSDoc: Module: draw

# Module: draw

### Methods

#### (inner) formatSVGLegend(labels, colors) → {string}

Format an SVG string with labels and colors.

##### Parameters:

Name | Type | Description
--- | --- | ---
`labels` | Array.<string> | The names for the label.
`colors` | Array.<integer> | The colors for each label.

Source:
  - draw.js, line 125

##### Returns:

SVG string with the labels and colors values formated as a legend.

Type
  string

#### (inner) makeLabel(position, text, Color, 1opt) → {THREE.Sprite}

Create a THREE object that displays 2D text, this implementation is based on the answer found here

##### Parameters:

Name | Type | Attributes | Description
--- | --- | --- | ---
`position` | Array.<float> |  | The x, y, and z location of the label.
`text` | string |  | with the text to be shown on screen.
`Color` | integer |  | Hexadecimal base that represents the color of the text.
`1` | float | <optional> | factor An optional scaling factor to determine the size of the labels.

Source:
  - draw.js, line 80

##### Returns:

Object with the text displaying in it.

Type
  THREE.Sprite

#### (inner) makeLine(start, end, color, width, transparent) → {THREE.Line}

Create a generic THREE.Line object

##### Parameters:

Name | Type | Description
--- | --- | ---
`start` | Array.<float> | The x, y and z coordinates of one of the ends of the line.
`end` | Array.<float> | The x, y and z coordinates of one of the ends of the line.
`color` | integer | Hexadecimal base that specifies the color of the line.
`width` | float | The width of the line being drawn.
`transparent` | boolean | Whether the line will be transparent or not.

Source:
  - draw.js, line 42

##### Returns:

Type
  THREE.Line